@@ -1,8 +1,8 @@
 import math
 
 def cosine_sim(vector1, vector2):
-    vector1 = list(vector1.values())
-    vector2 = list(vector2.values())
+    vector1 = list(vector1)
+    vector2 = list(vector2)
     dot_prod = 0
     for i, v in enumerate(vector1):
         dot_prod += v * vector2[i]
